@@ -13,10 +13,10 @@ bichon_optim <- function(x, model, T, method.param=1){
 	
 	mk    <- krig$mean; sk    <- krig$sd; alpha <- method.param
 	t <- (mk-T)/sk; tplus <- t + alpha; tminus <- t - alpha
-
+	crit <- rep(0, length(t))
 	G <- alpha*(pnorm(tplus)-pnorm(tminus)) - t*(2*pnorm(t) - pnorm(tplus) - pnorm(tminus)) - (2*dnorm(t) - dnorm(tplus) - dnorm(tminus))
 			
-	crit <- G*sk
+	crit[t != 'Inf' & t !='-Inf'] <- (G*sk)[t != 'Inf' & t != '-Inf']
 
 	return(crit)
 }
